@@ -16,6 +16,7 @@ from typing import Callable
 from typing import Generator
 
 from ckms.utils import b64decode
+from ckms.utils import b64encode
 
 
 class OctetB64(bytes):
@@ -38,4 +39,7 @@ class OctetB64(bytes):
         return cls(b64decode(value))
 
     def __repr__(self) -> str: # pragma: no cover
-        return f'OctetB64({super().__repr__()})'
\ No newline at end of file
+        return f'OctetB64({super().__repr__()})'
+
+    def serialize(self) -> str:
+        return bytes.decode(b64encode(self), 'ascii')
\ No newline at end of file
